%% Import data from text file
% Script for importing data from following text files:
%
%   'HE545_absorptionProPS.txt'
%   'ReferenceNitrate.txt'
%   'ReferenceSalinity.txt'


%% Import absorption data
filename = 'HE545_absorptionProPS.txt';
delimiterIn = '\t';
headerlinesIn = 39;
a = importdata(filename,delimiterIn,headerlinesIn);
AbsorptionRaw = a.data;

% Create absorption spectra table
absorption = AbsorptionRaw(:,2:end);

% Create wavelength variable
wavelength = AbsorptionRaw(:,1);


%% Import Nitrate reference data
filename = 'ReferenceNitrate.txt';
delimiterIn = '\t';
headerlinesIn = 39;
b = importdata(filename,delimiterIn,headerlinesIn);
NitrateRef = b.data;

% Create Nitrate reference spectrum
NO3ref_all = NitrateRef(:,2:end);
ReferenceNitrate=mean(NO3ref_all,2);


%% Import salinity reference data
filename = 'ReferenceSalinity.txt';
delimiterIn = '\t';
headerlinesIn = 39;
c = importdata(filename,delimiterIn,headerlinesIn);
SalRef = c.data;

% Create salinity reference spectrum
Salref_all = SalRef(:,2:end);
ReferenceSalinity=mean(Salref_all,2);


%% save variables
save('wavelength.mat','wavelength')
save('absorption.mat','absorption')
save('ReferenceNitrate.mat','ReferenceNitrate')
save('ReferenceSalinity.mat','ReferenceSalinity')


%% Clear temporary variables
clearvars AbsorptionRaw a b c delimiterIn filename headerlinesIn;
clearvars NitrateRef NO3ref_all SalRef Salref_all

